# ja_timex

![logo](img/logo_title_34_small.png){align=right}

`ja-timex` は、現代日本語で書かれた自然文に含まれる時間情報表現を抽出し`TIMEX3`と呼ばれるアノテーション仕様に変換することで、プログラムが利用できる形に規格化するルールベースの解析器です。

### 入力

```python
timex_parser.parse("彼は2008年4月から週に3回ジョギングを1時間行ってきた")
```

### 出力

```python
[<TIMEX3 tid="t0" type="DATE" value="2008-04-XX" text="2008年4月">,
 <TIMEX3 tid="t1" type="SET" value="P1W" freq="3X" text="週に3回">,
 <TIMEX3 tid="t2" type="DURATION" value="PT1H" text="1時間">]
```

## 概要
人間が言葉として表現する日付や時刻、期間、頻度といった時間情報は、実に多様な表現を持ちます。テキストにおける時間情報を正確に認識することは、そのテキストが意味する事象やその関係性の理解に必要不可欠です。そうした時間情報を扱う言語処理タスクやアプリケーションにおいては、テキスト中から時間情報に関する表現を抽出し、記述される表現と規格化された構造とを紐付け、プログラムから利用できるように変換しなければなりません。

そこで、時間情報にまつわる表現を網羅的に収集し抽出ルールを作成し、それを元にテキスト中から候補となる表現を取得、そして時間情報のアノテーション規格に対応付けることでプログラミング言語の時間型との変換を行うための、時間情報の解析器を作成しました。

## 機能

- ルールベースによる日本語テキストからの日付や時刻、期間や頻度といった時間情報表現の抽出
- 時間表現のdatetime形式への変換サポート

## 参考文献
本パッケージは、以下の論文で提案されている時間情報アノテーションの枠組みを元に作成しています。

1.  [小西光, 浅原正幸, & 前川喜久雄. (2013). 『現代日本語書き言葉均衡コーパス』 に対する時間情報アノテーション. 自然言語処理, 20(2), 201-221.](https://www.jstage.jst.go.jp/article/jnlp/20/2/20_201/_article/-char/ja/)
2.   [成澤克麻 (2014)「自然言語処理における数量表現の取り扱い」東北大学大学院 修士論文](http://www.cl.ecei.tohoku.ac.jp/publications/2015/mthesis2013_narisawa_submitted.pdf)
